@@ -114,11 +114,20 @@ MainWindow::initLogging ()
 void
 MainWindow::log (const QString &strText, int level /*= 10*/)
 {
+    QString strDisp;
+    QRegExp regex("^\"(.*)\"\\s*");
+    if (strText.indexOf (regex) != -1) {
+        strDisp = regex.cap (1);
+    } else {
+        strDisp = strText;
+    }
+
     QDateTime dt = QDateTime::currentDateTime ();
     QString strLog = QString("%1 : %2 : %3")
                      .arg(dt.toString ("yyyy-MM-dd hh:mm:ss.zzz"))
                      .arg(level)
-                     .arg(strText);
+                     .arg(strDisp);
+
 
     // Send to standard output
     cout << strLog.toStdString () << endl;
@@ -332,8 +341,12 @@ MainWindow::init ()
     this->setWindowIcon (icoGoogle);
 
     // Connect the signals from the Mosquitto thread
-    QObject::connect (&mqThread, SIGNAL(sigUpdateInbox()),
-                      &oInbox  , SLOT  (refresh()));
+    QObject::connect (&mqThread , SIGNAL(sigUpdateInbox()),
+                      &oInbox   , SLOT  (refresh()));
+    QObject::connect (&mqThread , SIGNAL(sigUpdateContacts()),
+                      &oContacts, SLOT  (refreshContacts()));
+    QObject::connect (&mqThread , SIGNAL(status(QString,int)),
+                       this     , SLOT  (setStatus(QString,int)));
 
     // If the cache has the username and password, begin login
     if (dbMain.getUserPass (strUser, strPass))
