@@ -16,12 +16,15 @@ MqClientThread::on_connect (int rc)
         qWarning() << "Mosquitto: Failed in on_connect. Error =" << rc;
         return;
     }
+    qDebug() << "Mosquitto: Connected to" << strHost;
 
     rc = this->subscribe (NULL, strTopic.toLatin1().constData ());
     if (0 != rc) {
         qWarning() << "Mosquitto: Failed in subscribe. Error =" << rc;
+        emit status ("Failed to subscribe to Mosquitto server");
         return;
     }
+    qDebug() << "Mosquitto: Subscribed to" << strTopic << "established.";
 }//MqClientThread::on_connect
 
 void
@@ -37,9 +40,13 @@ MqClientThread::on_message (const struct mosquitto_message *message)
              << ". message = " << strPayload;
 
     if (strPayload.startsWith ("inbox")) {
-        qDebug ("New inbox entry");
+        emit status ("Mosquitto: New inbox entry");
         emit sigUpdateInbox();
     }
+    if (strPayload.startsWith ("contact")) {
+        emit status ("Mosquitto: Contact changes");
+        emit sigUpdateContacts ();
+    }
 }//MqClientThread::on_message
 
 void
@@ -56,9 +63,12 @@ MqClientThread::run ()
         QHostInfo hInfo = QHostInfo::fromName (strHost);
         QString strFirst = hInfo.addresses().first().toString();
 
+        qDebug() << "Mosquitto: Attempting to connect to" << strHost
+                 << "at" << strFirst;
         int rv = ((mosquittopp*)this)->connect (strFirst.toLatin1().constData ());
         if (0 != rv) {
             qWarning() << "Mosquitto: Failed to connect. Error =" << rv;
+            emit status ("Failed to connect to Mosquitto server");
             break;
         }
 
@@ -66,6 +76,7 @@ MqClientThread::run ()
             this->loop (1*1000);
         }
 
+        qDebug ("Mosquitto: End Mq loop. Unsubscribe and disconnect");
         this->unsubscribe(NULL, strTopic.toLatin1().constData ());
         ((mosquittopp*)this)->disconnect ();
         this->loop (100);
